==> chaosmesh-model-6.0.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/DNSChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSChaosSpecBuilder extends DNSChaosSpecFluentImpl<DNSChaosSpecBuilder> implements VisitableBuilder<DNSChaosSpec,DNSChaosSpecBuilder>{
  public DNSChaosSpecBuilder() {
    this(false);
  }
  public DNSChaosSpecBuilder(Boolean validationEnabled) {
    this(new DNSChaosSpec(), validationEnabled);
  }
  public DNSChaosSpecBuilder(DNSChaosSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSChaosSpecBuilder(DNSChaosSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSChaosSpec(), validationEnabled);
  }
  public DNSChaosSpecBuilder(DNSChaosSpecFluent<?> fluent,DNSChaosSpec instance) {
    this(fluent, instance, false);
  }
  public DNSChaosSpecBuilder(DNSChaosSpecFluent<?> fluent,DNSChaosSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAction(instance.getAction()); 
    fluent.withDuration(instance.getDuration()); 
    fluent.withMode(instance.getMode()); 
    fluent.withPatterns(instance.getPatterns()); 
    fluent.withScheduler(instance.getScheduler()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  public DNSChaosSpecBuilder(DNSChaosSpec instance) {
    this(instance,false);
  }
  public DNSChaosSpecBuilder(DNSChaosSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAction(instance.getAction()); 
    this.withDuration(instance.getDuration()); 
    this.withMode(instance.getMode()); 
    this.withPatterns(instance.getPatterns()); 
    this.withScheduler(instance.getScheduler()); 
    this.withSelector(instance.getSelector()); 
    this.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  DNSChaosSpecFluent<?> fluent;
  Boolean validationEnabled;
  public DNSChaosSpec build() {
    DNSChaosSpec buildable = new DNSChaosSpec(fluent.getAction(),fluent.getDuration(),fluent.getMode(),fluent.getPatterns(),fluent.getScheduler(),fluent.getSelector(),fluent.getValue());
    return buildable;
  }
  
}

==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/DNSChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSChaosSpecBuilder extends DNSChaosSpecFluentImpl<DNSChaosSpecBuilder> implements VisitableBuilder<DNSChaosSpec,DNSChaosSpecBuilder>{
  public DNSChaosSpecBuilder() {
    this(false);
  }
  public DNSChaosSpecBuilder(Boolean validationEnabled) {
    this(new DNSChaosSpec(), validationEnabled);
  }
  public DNSChaosSpecBuilder(DNSChaosSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSChaosSpecBuilder(DNSChaosSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSChaosSpec(), validationEnabled);
  }
  public DNSChaosSpecBuilder(DNSChaosSpecFluent<?> fluent,DNSChaosSpec instance) {
    this(fluent, instance, false);
  }
  public DNSChaosSpecBuilder(DNSChaosSpecFluent<?> fluent,DNSChaosSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAction(instance.getAction()); 
    fluent.withContainerNames(instance.getContainerNames()); 
    fluent.withDuration(instance.getDuration()); 
    fluent.withMode(instance.getMode()); 
    fluent.withPatterns(instance.getPatterns()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  public DNSChaosSpecBuilder(DNSChaosSpec instance) {
    this(instance,false);
  }
  public DNSChaosSpecBuilder(DNSChaosSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAction(instance.getAction()); 
    this.withContainerNames(instance.getContainerNames()); 
    this.withDuration(instance.getDuration()); 
    this.withMode(instance.getMode()); 
    this.withPatterns(instance.getPatterns()); 
    this.withSelector(instance.getSelector()); 
    this.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  DNSChaosSpecFluent<?> fluent;
  Boolean validationEnabled;
  public DNSChaosSpec build() {
    DNSChaosSpec buildable = new DNSChaosSpec(fluent.getAction(),fluent.getContainerNames(),fluent.getDuration(),fluent.getMode(),fluent.getPatterns(),fluent.getSelector(),fluent.getValue());
    return buildable;
  }
  
}
